==> sd-auth-client-mongo-1.0.1-sources.jar: systems/dennis/shared/auth_client/SecurityUtils.java <==
package systems.dennis.shared.auth_client;

import jakarta.servlet.http.HttpServletRequest;
import lombok.SneakyThrows;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;
import systems.dennis.shared.annotations.security.ISecurityUtils;
import systems.dennis.shared.auth_client.client.TokenProviderClient;
import systems.dennis.shared.auth_client.form.UserTokenDTO;
import systems.dennis.shared.config.WebContext;
import systems.dennis.shared.entity.AbstractEntity;
import systems.dennis.shared.entity.TokenData;
import systems.dennis.shared.exceptions.AuthorizationNotFoundException;
import systems.dennis.shared.model.AbstractUserAssignableElement;
import systems.dennis.shared.utils.ApplicationContext;

import java.io.Serializable;

@Service @Primary
public class SecurityUtils<T extends Serializable> extends ApplicationContext implements ISecurityUtils<T> {
    private HttpServletRequest request;
    public static final String AUTHORIZATION_HEADER = "Authorization";
    String AUTH_TYPE_HEADER = "AUTH_TYPE";
    String AUTH_SCOPE_HEADER = "AUTH_SCOPE";
    public SecurityUtils(WebContext context, HttpServletRequest request) {
        super(context);
        this.request = request;
    }

    @Override
    public  T getUserDataId() {
        return (T) tokenFromHeader().getUserData().getId();
    }

    @SneakyThrows
    public UserTokenDTO tokenFromHeader() throws AuthorizationNotFoundException {

        return getBean(TokenProviderClient.class).getAuthentication(getToken());

    }


    public TokenData getToken() {

        if (request == null) {
            return null;
        }
        String token = request.getHeader(AUTHORIZATION_HEADER);
        String tokenScope = request.getHeader(AUTH_SCOPE_HEADER);

        if (token == null) {
            throw  new AuthorizationNotFoundException("Expected token, instead no token");

        }

        token = token.replace("Bearer ", "").trim();
        return new TokenData( tokenScope,token);
    }



        @Override
    public void assignUser(AbstractEntity<T> pojo) {
        pojo.setId(getCurrentUser());
    }

    @Override
    public void assignUser(AbstractEntity<T> pojo, AbstractEntity<T> pojoOriginal) {
        if (pojo instanceof AbstractUserAssignableElement) {
            ((AbstractUserAssignableElement) pojo).setUserDataId(((AbstractUserAssignableElement) pojoOriginal).getUserDataId());
        }
    }


    @Override
    public boolean isAdmin() {
        return hasRole("ROLE_ADMIN");
    }

    @Override
    public boolean hasRole(String role) {
        return  tokenFromHeader().getRoleList().contains(role);
    }

    @Override
    public String getUserLanguage() {
        return tokenFromHeader().getUserData().getPreferredLanguage();
    }

    public UserTokenDTO get() {
        return tokenFromHeader();
    }
}

==> sd-auth-client-mongo-1.0.3-sources.jar: systems/dennis/shared/auth_client/SecurityUtils.java <==
package systems.dennis.shared.auth_client;

import jakarta.servlet.http.HttpServletRequest;
import lombok.SneakyThrows;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;
import systems.dennis.shared.annotations.security.ISecurityUtils;
import systems.dennis.shared.auth_client.client.TokenProviderClient;
import systems.dennis.shared.auth_client.form.UserTokenDTO;
import systems.dennis.shared.beans.IdToAuthorizationIdBean;
import systems.dennis.shared.config.WebContext;
import systems.dennis.shared.entity.AbstractEntity;
import systems.dennis.shared.entity.TokenData;
import systems.dennis.shared.exceptions.AuthorizationNotFoundException;

import systems.dennis.shared.utils.ApplicationContext;

import java.io.Serializable;

@Service @Primary
public class SecurityUtils<T extends Serializable> extends ApplicationContext implements ISecurityUtils<T> {
    private HttpServletRequest request;
    private final IdToAuthorizationIdBean id2id;
    public static final String AUTHORIZATION_HEADER = "Authorization";
    String AUTH_TYPE_HEADER = "AUTH_TYPE";
    String AUTH_SCOPE_HEADER = "AUTH_SCOPE";
    public SecurityUtils(WebContext context, HttpServletRequest request, IdToAuthorizationIdBean id2id) {
        super(context);
        this.request = request;
        this.id2id = id2id;
    }

    @Override
    public  T getUserDataId() {
        return (T) id2id.idToAuthorizationId( tokenFromHeader().getUserData().getId());
    }

    @SneakyThrows
    public UserTokenDTO tokenFromHeader() throws AuthorizationNotFoundException {

        return getBean(TokenProviderClient.class).getAuthentication(getToken());

    }


    public TokenData getToken() {

        if (request == null) {
            return null;
        }
        String token = request.getHeader(AUTHORIZATION_HEADER);
        String tokenScope = request.getHeader(AUTH_SCOPE_HEADER);

        if (token == null) {
            throw  new AuthorizationNotFoundException("Expected token, instead no token");

        }

        token = token.replace("Bearer ", "").trim();
        return new TokenData( tokenScope,token);
    }


    @Override
    public boolean isAdmin() {
        return hasRole("ROLE_ADMIN");
    }

    @Override
    public boolean hasRole(String role) {
        return  tokenFromHeader().getRoleList().contains(role);
    }

    @Override
    public String getUserLanguage() {
        return tokenFromHeader().getUserData().getPreferredLanguage();
    }

    public UserTokenDTO get() {
        return tokenFromHeader();
    }
}
